@@ -19,19 +19,16 @@ use event_processor::*;
 use sqs_completion_handler::*;
 use sqs_consumer::*;
 use sqs_lambda::completion_event_serializer::CompletionEventSerializer;
-use sqs_lambda::event_decoder::PayloadDecoder;
-use sqs_lambda::event_emitter::S3EventEmitter;
-use sqs_lambda::event_handler::{EventHandler, OutputEvent, Completion};
+use sqs_lambda::event_decoder::EventDecoder;
+use sqs_lambda::event_emitter::{S3EventEmitter};
+use sqs_lambda::event_handler::EventHandler;
 use sqs_lambda::event_processor;
-use sqs_lambda::event_retriever::S3PayloadRetriever;
+use sqs_lambda::event_retriever::S3EventRetriever;
 use sqs_lambda::sqs_completion_handler;
 use sqs_lambda::sqs_consumer;
-use sqs_lambda::redis_cache::RedisCache;
 
 #[derive(Debug, Clone)]
-struct MyService {
-    cache: RedisCache,
-}
+struct MyService {}
 
 #[async_trait]
 impl EventHandler for MyService {
@@ -39,15 +36,10 @@ impl EventHandler for MyService {
     type OutputEvent = Subgraph;
     type Error = ();
 
-    async fn handle_event(&mut self, _input: Self::InputEvent) -> OutputEvent<Self::OutputEvent, Self::Error> {
+    async fn handle_event(&mut self, _input: Self::InputEvent) -> Result<Self::OutputEvent, Self::Error> {
         // do some work
-        let mut completed = OutputEvent::new(Completion::Total(Subgraph{}));
-
-        for input in _input.keys() {
-            completed.add_identity(input);
-        }
-        completed
 
+        Ok(Subgraph {})
     }
 }
 
@@ -76,7 +68,7 @@ impl CompletionEventSerializer for SubgraphSerializer {
     fn serialize_completed_events(
         &mut self,
         completed_events: &[Self::CompletedEvent],
-    ) -> Result<Vec<Self::Output>, Self::Error> {
+    ) -> Result<Self::Output, Self::Error> {
         let mut subgraph = Subgraph {};
         for sg in completed_events {
             subgraph.merge(sg);
@@ -90,9 +82,10 @@ impl CompletionEventSerializer for SubgraphSerializer {
 #[derive(Clone)]
 pub struct ZstdProtoDecoder;
 
-impl<E> PayloadDecoder<E> for ZstdProtoDecoder
+impl<E> EventDecoder<E> for ZstdProtoDecoder
     where E: Message + Default
 {
+
     fn decode(&mut self, body: Vec<u8>) -> Result<E, Box<dyn Error>>
         where E: Message + Default,
     {
@@ -104,6 +97,7 @@ impl<E> PayloadDecoder<E> for ZstdProtoDecoder
 
         Ok(E::decode(decompressed)?)
     }
+
 }
 
 #[derive(Clone, Default)]
@@ -111,8 +105,9 @@ pub struct ZstdDecoder {
     pub buffer: Vec<u8>
 }
 
-impl PayloadDecoder<Vec<u8>> for ZstdDecoder
+impl EventDecoder<Vec<u8>> for ZstdDecoder
 {
+
     fn decode(&mut self, body: Vec<u8>) -> Result<Vec<u8>, Box<dyn Error>>
     {
         self.buffer.clear();
@@ -130,9 +125,10 @@ pub struct ZstdJsonDecoder {
     pub buffer: Vec<u8>
 }
 
-impl<E> PayloadDecoder<E> for ZstdJsonDecoder
+impl<E> EventDecoder<E> for ZstdJsonDecoder
     where E: for<'a> Deserialize<'a>
 {
+
     fn decode(&mut self, body: Vec<u8>) -> Result<E, Box<dyn Error>>
     {
         self.buffer.clear();
@@ -174,17 +170,16 @@ fn time_based_key_fn(_event: &[u8]) -> String {
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
     tokio::spawn(async move {
-        let cache = RedisCache::new("address".to_owned()).expect("Could not create redis client");
-
-
         let consume_policy = ConsumePolicy::new(
             unimplemented!(), // Use the Context.deadline from the lambda_runtime
             Duration::from_secs(5), // Stop consuming when there's 10 seconds left in the runtime
-            3, // Maximum of 3 empty receives before we stop
         );
 
         let (tx, shutdown_notify) = tokio::sync::oneshot::channel();
 
+        let sqs_consumer = SqsConsumerActor::new(
+            SqsConsumer::new(init_sqs_client(), "queue_url".into(), consume_policy, tx)
+        );
 
         let sqs_completion_handler = SqsCompletionHandlerActor::new(
             SqsCompletionHandler::new(
@@ -199,19 +194,7 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
                 CompletionPolicy::new(
                     1000, // Buffer up to 1000 messages
                     Duration::from_secs(30), // Buffer for up to 30 seconds
-                ),
-                |_, _| {}
-            )
-        );
-
-
-        let sqs_consumer = SqsConsumerActor::new(
-            SqsConsumer::new(
-                init_sqs_client(),
-                "queue_url".into(),
-                consume_policy,
-                sqs_completion_handler.clone(),
-                tx
+                )
             )
         );
 
@@ -221,9 +204,8 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
                 EventProcessorActor::new(EventProcessor::new(
                     sqs_consumer.clone(),
                     sqs_completion_handler.clone(),
-                    MyService { cache: cache.clone() },
-                    S3PayloadRetriever::new(init_s3_client(), ZstdJsonDecoder::default()),
-                    cache.clone()
+                    MyService {},
+                    S3EventRetriever::new(init_s3_client(), ZstdJsonDecoder::default()),
                 ))
             })
             .collect();
@@ -234,6 +216,7 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         let _ = shutdown_notify.await;
 
         tokio::time::delay_for(Duration::from_millis(100)).await;
+
     });
 
     Ok(())
